@@ -3,7 +3,7 @@
 
 package HiD::Processor::IIBlog;
 our $AUTHORITY = 'cpan:GENEHACK';
-$HiD::Processor::IIBlog::VERSION = '1.99';
+$HiD::Processor::IIBlog::VERSION = '1.991';
 use Moose;
 extends 'HiD::Processor';
 use namespace::autoclean;
@@ -39,7 +39,7 @@ sub BUILDARGS {
       function => {
         commafy     => sub { my $a = shift; join ',' , @$a },
         lc          => sub { lc( shift ) } ,
-        lightbox    => \&lightbox,
+        lightbox    => \&_lightbox,
         pretty_date => sub { shift->strftime( "%d %b %Y" ) },
       } ,
       path => $path,
@@ -127,7 +127,7 @@ C<17 Aug 2017>.
 
 =head1 VERSION
 
-version 1.99
+version 1.991
 
 =head1 AUTHOR
 
